package Email::Filter::AutoReply;

use base 'Email::Filter';

=head1 NAME

Email::Filter::AutoReply - Email::Filter for autoresponding.

=head1 DESCRIPTION

NOT IMPLEMENTED, and probably won't be unless someone does.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2004 by Adam Monsen

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.3 or,
at your option, any later version of Perl 5 you may have available.

See E<lt>http://www.perl.com/perl/misc/Artistic.htmlE<gt>

=cut

1;
